pub struct Icon;Expand description
Helper type for the icon field of PublicKeyCredentialRpEntity.
This field must be parsed but not used or stored. Therefore this wrapper type can be deserialized from a string but does not store any data.